@@ -77,10 +77,12 @@ def get_planning(elements = ['grid5000'], vlan = False, subnet = False, storage
     if 'grid5000' in elements:
         sites = get_g5k_sites()
     else:
-        sites = list(set([ site for site in elements if site in get_g5k_sites() ]+\
-                    [ get_cluster_site(cluster) for cluster in elements
-                     if cluster in get_g5k_clusters() ]))
-
+        sites = list(set([site for site in elements if site in get_g5k_sites()]+\
+                    [get_cluster_site(cluster) for cluster in elements
+                     if cluster in get_g5k_clusters()]))
+    if len(sites) == 0:
+        logger.error('Wrong elements given, must be one of the following values \n %s \n%s', elements)
+        return None
     planning = {}
     for site in sites:
         planning[site] = {}
@@ -89,11 +91,11 @@ def get_planning(elements = ['grid5000'], vlan = False, subnet = False, storage
 
     for site in sites:
         if vlan:
-            planning[site].update( { 'vlans': {} } )
+            planning[site].update({'vlans': {}})
         if subnet:
-            planning[site].update( { 'subnets': {} } )
+            planning[site].update({'subnets': {}})
         if storage:
-            planning[site].update( { 'storage': {} } )
+            planning[site].update({'storage': {}})
 
     if _retrieve_method == 'API':
         _get_planning_API(planning)
@@ -143,7 +145,7 @@ def compute_slots(planning, walltime, excluded_elements = None):
     kavlan = False
     kavlan_global = False
     if 'vlans' in (planning.itervalues().next().keys()):
-        if len(planning.keys()) >1:
+        if len(planning.keys()) > 1:
             kavlan_global = True
         else:
             kavlan = True
@@ -171,7 +173,7 @@ def compute_slots(planning, walltime, excluded_elements = None):
                             free_elements['grid5000'] += 1
                             free_elements[site] += 1
                             free_elements[cluster] += 1
-                            log += ', '+host
+                            log += ', ' + host
 
             if kavlan:
                 free_vlans = 0
@@ -194,11 +196,9 @@ def compute_slots(planning, walltime, excluded_elements = None):
                         if kavlan_global_free:
                             free_vlans_global.append(site)
                 free_elements['kavlan'] = free_vlans_global
-
-
                 ## MISSING OTHER RESOURCES COMPUTATION
 
-        slots.append( [ limit, limit + walltime, free_elements] )
+        slots.append([ limit, limit + walltime, free_elements])
 
     slots.sort()
     return slots
@@ -220,8 +220,9 @@ def find_first_slot( slots, resources_wanted):
             elif isinstance(slot[2]['kavlan'], list):
                 if len(slot[2]['kavlan']) == 0:
                     vlan_free = False
-        res_nodes = sum( [ nodes for element, nodes in slot[2].iteritems() if element in resources_wanted
+        res_nodes = sum([ nodes for element, nodes in slot[2].iteritems() if element in resources_wanted
                           and element != 'kavlan'])
+
         if res_nodes > 0 and vlan_free:
             return slot
 
@@ -443,7 +444,7 @@ def distribute_hosts(resources_available, resources_wanted, excluded_elements =
     clusters_wanted = {}
     for element, n_nodes in resources_wanted.iteritems():
         if element in get_g5k_clusters():
-            clusters_wanted[element] =  n_nodes
+            clusters_wanted[element] = n_nodes
     for cluster, n_nodes in clusters_wanted.iteritems():
         nodes = n_nodes if n_nodes > 0 else resources_available[cluster]
         resources_available[get_cluster_site(cluster)] -= nodes
@@ -459,7 +460,7 @@ def distribute_hosts(resources_available, resources_wanted, excluded_elements =
     #Defining the sites you want
     sites_wanted = {}
     for element, n_nodes in resources_wanted.iteritems():
-        if element in get_g5k_sites():
+        if element in get_g5k_sites() and element not in excluded_elements:
             sites_wanted[element] = n_nodes
     for site, n_nodes in sites_wanted.iteritems():
         resources[site] = n_nodes if n_nodes > 0 else resources_available[site]
